#if defined _mm_included
  #endinput
#endif
#define _mm_included

#include <mm_const> 

#if AMXX_VERSION_NUM >= 175
    #pragma reqlib mm
    #if !defined AMXMODX_NOAUTOLOAD
        #pragma loadlib mm
    #endif
#else
    #pragma library mm
#endif

/**
 * Sets/gets players data.
 *
 * @param id      player index.
 * @param pd      enum PLAYERDATA.
 * @param value   new value.
 * @return        playerdata.
 */
native mm_get_playerdata(id, pd);
native mm_set_playerdata(id, pd, value);

/**
 * Gets class count.
 *
 * @param class   class to get.
 * @return        count or ID if Murderer or gun holder.
 */
native mm_get_classcount(class);

/**
 * Sets/gets game mode.
 *
 * @param value   sets new game mode.
 * @return        game mode.
 */
native mm_get_gamemode();
native mm_set_gamemode(value);

/**
 * Sets/gets winner.
 *
 * @param value   sets new winner.
 * @return        winner.
 */
native mm_get_winner();
native mm_set_winner(value);

/**
 * Gets roundtime.
 *
 * @return        roundtime.
 */
native Float:mm_get_roundtime();

/**
 * Give player a Murder knife.
 *
 * @param id      player id.
 * @param ent     knife entity to give, can be 0.
 * @return        roundtime.
 */
native mm_give_knife(id, ent);

/**
 * Returns player name.
 *
 * @param id      player id.
 * @param string  place to store name.
 * @return        true.
 */
native mm_get_playername(id, string[]);

/**
 * Register cvar to file.
 *
 * @param name[]        cvar name.
 * @param string[]      cvar value.
 * @param description[] cvar description.
 * @return              true/false.
 */
native mm_register_cvar(name[], string[], description[]);

/**
 * Called when game mode changes.
 *
 * @param mode      game mode.
 */
forward mm_gamemode(mode);

/**
 * Called when winner is set.
 *
 * @param winner    winner.
 */
forward mm_winner(winner);

/**
 * Called when dead body is created.
 *
 * @param owner     player id.
 * @param ent       entity id.
 */
forward ttt_spawnbody(owner, ent);

#include <mm_stocks>
