#include <amxmodx>
#include <fakemeta>
#include <murdermod>

new const g_szNewRadio[][] =
{
  "murdermod/hi01.wav",
  "murdermod/no02.wav",
  "murdermod/help01.wav",
  "murdermod/behindyou02.wav",
  "murdermod/watchout.wav",
  "murdermod/answer30.wav",
  "murdermod/gordead_ques07.wav",
  "murdermod/answer22.wav",
  "murdermod/gethellout.wav",
  "murdermod/notthemanithought01.wav",
  "murdermod/question25.wav",
  "murdermod/question30.wav",
  "murdermod/runforyourlife01.wav",
  "murdermod/whoops01.wav"
};

new const g_szNewNames[][] =
{
  "Hi.",
  "No!",
  "Help!",
  "Behind you!",
  "Watch out!",
  "You talking to me?",
  "Look, he is dead!",
  "You never know...",
  "Get the hell out!",
  "Not the man I thought u were...",
  "One of those days.",
  "No kids around.",
  "Run for your life!",
  "Whoops."
};

new Float:g_fNextSound[33], g_iSoundCount[33];
new cvar_sound_maxcount;

public plugin_precache()
{
  for(new i = 0; i < sizeof(g_szNewRadio); i++)
    precache_sound(g_szNewRadio[i]);
}

public plugin_init()
{
  register_plugin("[MM] Radio commands", MM_VERSION, MM_AUTHOR);

  cvar_sound_maxcount = my_register_cvar("mm_sound_maxcount", "20", "Max amount of radio messages. (Default: 20)");
  register_clcmd("radio1", "radio_menu_show");
  register_clcmd("radio2", "radio_menu_show");
  register_clcmd("radio3", "radio_menu_show");
  register_clcmd("radio4", "radio_menu_show");

  new commands[][] =
  {
    "coverme", "takepoint", "holdpos", "regroup", "followme", "takingfire",
    "go", "fallback", "sticktog", "getinpos", "stormfront", "report",
    "roger", "enemyspot", "needbackup", "sectorclear", "inposition", "reportingin", "getout", "negative", "enemydown"
  };

  for(new i = 0; i < sizeof(commands); i++)
    register_clcmd(commands[i], "cmd_blockalias");
}

public mm_gamemode(mode)
{
  if(mode == GAME_STARTED)
  {
    new id, num;
    static players[32];
    get_players(players, num);
    for(--num; num >= 0; num--)
    {
      id = players[num];
      g_iSoundCount[id] = false;
    }
  }
}

public cmd_blockalias(id)
  return PLUGIN_HANDLED;

public radio_menu_show(id)
{
  if(is_user_alive(id) && g_fNextSound[id] < get_gametime() && mm_get_gamemode() == GAME_STARTED && g_iSoundCount[id] < get_pcvar_num(cvar_sound_maxcount))
  {
    static menu;
    menu = menu_create("Radio menu", "radio_menu_handle");

    new data[3];
    for(new i = 0; i < sizeof(g_szNewRadio); i++)
    {
      num_to_str(i, data, charsmax(data));
      menu_additem(menu, g_szNewNames[i], data, 0);
    }

    menu_display(id, menu);
  }

  return PLUGIN_HANDLED;
}

public radio_menu_handle(id, menu, item)
{
  if(item == MENU_EXIT || !is_user_alive(id) || g_fNextSound[id] > get_gametime() || mm_get_gamemode() != GAME_STARTED || g_iSoundCount[id] > get_pcvar_num(cvar_sound_maxcount))
  {
    menu_destroy(menu);
    return PLUGIN_HANDLED;
  }

  new access, callback, num[3];
  menu_item_getinfo(menu, item, access, num, charsmax(num), _, _, callback);
  menu_destroy(menu);

  new pick = str_to_num(num);
  g_fNextSound[id] = GetWavDuration(g_szNewRadio[pick]);
  if(g_fNextSound[id] < 1.5)
    g_fNextSound[id] = get_gametime() + 1.5;
  else g_fNextSound[id] = get_gametime() + g_fNextSound[id];

  g_iSoundCount[id]++;
  emit_sound(id, CHAN_VOICE, g_szNewRadio[pick], 1.0, ATTN_NORM, 0, PITCH_NORM);
  client_print(0, print_chat, "%s (RADIO): %s", get_name(id), g_szNewNames[pick]);

  return PLUGIN_HANDLED;
}

// By Arkshine
Float:GetWavDuration(const WavFile[])
{
  new Frequence[4];
  new Bitrate[2];
  new DataLength[4];
  new File;
  static fulldest[64];

  // --| Open the file.
  formatex(fulldest, charsmax(fulldest), "sound/%s", WavFile);
  File = fopen(fulldest, "rb");

  // --| Get the frequence from offset 24. ( Read 4 bytes )
  fseek(File, 24, SEEK_SET);
  fread_blocks(File, Frequence, 4, BLOCK_INT);
  
  // --| Get the bitrate from offset 34. ( read 2 bytes )
  fseek(File, 34, SEEK_SET); 
  fread_blocks(File, Bitrate, 2, BLOCK_BYTE);
  
  // --| Search 'data'. If the 'd' not on the offset 40, we search it.
  if(fgetc(File) != 'd') while(fgetc(File) != 'd' && !feof(File)) {}
  
  // --| Get the data length from offset 44. ( after 'data', read 4 bytes )
  fseek(File, 3, SEEK_CUR); 
  fread_blocks(File, DataLength, 4, BLOCK_INT);

  // --| Close file.
  fclose(File);
  
  // --| Calculate the time. ( Data length / ( frequence * bitrate ) / 8 ).
  return float(DataLength[0]) / (float(Frequence[0] * Bitrate[0]) / 8.0);
}
